"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.executePreflightChecks = exports.preflightChecksEnabled = void 0;
const log_1 = require("../../log");
const http_1 = require("./http");
function preflightChecksEnabled(config) {
    // preflight checks are enabled per default
    let preflightChecksEnabled = true;
    const preflightChecksEnabledValue = config
        .PREFLIGHT_CHECKS_ENABLED;
    if (typeof preflightChecksEnabledValue !== 'undefined') {
        preflightChecksEnabled =
            preflightChecksEnabledValue.toLowerCase() === 'true' ||
                preflightChecksEnabledValue.toLowerCase() === 'yes';
    }
    log_1.log.info({ enabled: preflightChecksEnabled }, 'verifying if preflight checks are enabled');
    return preflightChecksEnabled;
}
exports.preflightChecksEnabled = preflightChecksEnabled;
async function executePreflightChecks(config) {
    const preflightChecks = [];
    const httpChecks = (0, http_1.getHttpChecks)(config).filter((c) => c.enabled);
    preflightChecks.push(...httpChecks);
    const preflightCheckResults = [];
    const results = await Promise.allSettled(preflightChecks.map(async (c) => c.check(config)));
    results.forEach((r) => {
        if (r.status === 'fulfilled') {
            preflightCheckResults.push(r.value);
        }
        else {
            log_1.log.error({ error: r.reason }, 'Unexpected error when executing checks');
        }
    });
    logPreflightCheckResults(preflightCheckResults);
    return Promise.resolve(preflightCheckResults);
}
exports.executePreflightChecks = executePreflightChecks;
const logPreflightCheckResults = (results) => {
    console.log('##############################################################');
    console.log('### PREFLIGHT CHECKS RESULTS');
    console.log('###');
    console.log('### Preflight checks help to catch errors early, upon broker');
    console.log('### client startup. Note, that broker client will start');
    console.log('### whether the checks were successful or not.');
    console.log('###');
    console.log('### See more: https://github.com/snyk/broker#preflight-checks');
    console.log('##############################################################');
    const checks = results.map((check) => {
        return { id: check.id, status: check.status };
    });
    console.table(checks);
};
//# sourceMappingURL=index.js.map